@@ -3,7 +3,7 @@ import json
 from django.conf import settings
 from paypal.standard.ipn.signals import valid_ipn_received
 from paypal.standard.models import ST_PP_COMPLETED
-from plans.models import UserPlan, Order, Pricing
+from plans.models import Order, Pricing, UserPlan
 
 from .models import PayPalPayment
 
@@ -15,19 +15,22 @@ def show_me_the_money(sender, **kwargs):
     print(ipn_obj.receiver_email)
     print(ipn_obj.txn_type)
 
-    if not (ipn_obj.is_subscription_cancellation() or ipn_obj.is_subscription_payment()):
+    if not (
+        ipn_obj.is_subscription_cancellation() or ipn_obj.is_subscription_payment()
+    ):
         # Not a subscription
         return
 
     custom = json.loads(ipn_obj.custom)
-    order = Order.objects.get(pk=custom['first_order_id'])
+    order = Order.objects.get(pk=custom["first_order_id"])
     print("Order: ", order.id)
-    user_plan = UserPlan.objects.get(pk=custom['user_plan_id'])
-    PayPalPayment.objects.create(paypal_ipn=ipn_obj, user_plan=user_plan, order=order)
+    user_plan = UserPlan.objects.get(pk=custom["user_plan_id"])
 
-    if ipn_obj.is_subscription_cancellation() and hasattr(user_plan, 'recurring'):
+    if ipn_obj.is_subscription_cancellation() and hasattr(user_plan, "recurring"):
         user_plan.recurring.delete()
-    elif ipn_obj.is_subscription_payment() and ipn_obj.payment_status == ST_PP_COMPLETED:
+    elif (
+        ipn_obj.is_subscription_payment() and ipn_obj.payment_status == ST_PP_COMPLETED
+    ):
         # WARNING !
         # Check that the receiver email is the same we previously
         # set on the `business` field. (The user could tamper with
@@ -38,14 +41,16 @@ def show_me_the_money(sender, **kwargs):
             bussiness_email = settings.PAYPAL_TEST_BUSSINESS_EMAIL
         if ipn_obj.receiver_email != bussiness_email:
             # Not a valid payment
-            raise Exception(f"Returned email doesn't mathch: {ipn_obj.receiver_email} != {bussiness_email}")
+            raise Exception(
+                f"Returned email doesn't mathch: {ipn_obj.receiver_email} != {bussiness_email}"
+            )
 
         # ALSO: for the same reason, you need to check the amount
         # received, `custom` etc. are all what you expect or what
         # is allowed.
 
         # Undertake some action depending upon `ipn_obj`.
-        pricing = Pricing.objects.get(pk=custom['pricing_id'])
+        pricing = Pricing.objects.get(pk=custom["pricing_id"])
         if order.status == Order.STATUS.COMPLETED:
             order = Order.objects.create(
                 user=user_plan.user,
@@ -57,11 +62,17 @@ def show_me_the_money(sender, **kwargs):
         user_plan.set_plan_renewal(
             order,
             token=ipn_obj.subscr_id,
-            payment_provider="paypal-recurring" + ("-sandbox" if ipn_obj.test_ipn else ""),
+            payment_provider="paypal-recurring"
+            + ("-sandbox" if ipn_obj.test_ipn else ""),
             has_automatic_renewal=True,
             token_verified=True,
         )
+        PayPalPayment.objects.create(
+            paypal_ipn=ipn_obj, user_plan=user_plan, order=order
+        )  # use the new order
         order.complete_order()
+        return
+    PayPalPayment.objects.create(paypal_ipn=ipn_obj, user_plan=user_plan, order=order)
 
 
 valid_ipn_received.connect(show_me_the_money)
